#
# spec file for package python-pykerberos
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-pykerberos
Version:        1.2.4
Release:        2.1
Summary:        High-level interface to Kerberos
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/02strich/pykerberos/
Source:         https://files.pythonhosted.org/packages/source/p/pykerberos/pykerberos-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(krb5)
# https://github.com/02strich/pykerberos/issues/17
Conflicts:      python-kerberos
%python_subpackages

%description
This Python package is a high-level wrapper for Kerberos (GSSAPI) operations.
The goal is to avoid having to build a module that wraps the entire Kerberos.framework,
and instead offer a limited set of functions that do what is needed for client/server
Kerberos authentication based on <http://www.ietf.org/rfc/rfc4559.txt>.

%prep
%setup -q -n pykerberos-%{version}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install

%files %{python_files}
%doc README.txt
%license LICENSE
%{python_sitearch}/kerberos.cpython*
%{python_sitearch}/pykerberos-%{version}*-info

%changelog
* Tue Jun 10 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Wed Oct  5 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v1.2.4 (9 Nov 2021)
  * Added C API change support for Python 3.10 (thanks @stevenpackardblp!)
  * Fixed a pointer alignment issue that impacted M1 Mac users (thanks @devashish2203!)
* Tue Feb  5 2019 Thomas Bechtold <tbechtold@suse.com>
- update to 1.2.1:
  * add crusty CMake support
  * minor change to CBT struct
  * get build working on OSX again
  * changes based on upstream PR
  * add CHANGELOG with entries for 1.2.1.beta1
  * add winrm-style IOV encryption support
  * bump repo version to 1.2.1dev
  * Removing 3.2 from travis b/c it is no longer fully supported
  * Added method to build the CBT structure and modified authGSSClientStep
    to pass along this CBT structure if it is set
  * obviously, verify shouldn't be const
  * 1.2.1 final release
  * Adding life support note to README
- Use %%license macro
* Wed Dec 20 2017 dmueller@suse.com
- remove explicit krb5 requires, this is in conflict with
  krb5-mini, which causes depending packages to build-fail
* Tue Aug 22 2017 tbechtold@suse.com
- update to 1.1.14
- convert to singlespec
* Thu Sep  1 2016 tbechtold@suse.com
  update to version v1.1.13
  * Fix TypeError when krb5-config is not present
  * Don't free stack allocated buffer #15
  * Bump version to 1.1.11
  * Fix reference to undefined command_name variable
  * Remove  reference to undefined popenargs variable
  * Increment version to v1.1.13
  * Address endless loop in case neither krb5-config nor krb5-config.mit are found
  * remove deprecation warning for clean methods
  * Add travis config
  * replace explicit client credentials to gss_init_sec_context
  * Increment version to 1.1.12
  * Add a dummy test script
- Use pypi.io as Source url
* Mon Mar 14 2016 dmueller@suse.com
- add conflicts to python-kerberos
* Tue Feb  9 2016 tbechtold@suse.com
- Initial packaging (version 1.1.10)
